Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(163)

Unified Diff: src/core/SkPictureRecord.cpp

Issue 20806003: Plumb in "bleed" flag (Closed) Base URL: http://skia.googlecode.com/svn/trunk/
Patch Set: Addressed pipe-specific issues and updated to ToT Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/core/SkPictureRecord.cpp
===================================================================
--- src/core/SkPictureRecord.cpp (revision 10709)
+++ src/core/SkPictureRecord.cpp (working copy)
@@ -913,9 +913,10 @@
}
void SkPictureRecord::drawBitmapRectToRect(const SkBitmap& bitmap, const SkRect* src,
- const SkRect& dst, const SkPaint* paint) {
- // id + paint index + bitmap index + bool for 'src'
- uint32_t size = 4 * kUInt32Size;
+ const SkRect& dst, const SkPaint* paint,
+ DrawBitmapRectFlags flags) {
+ // id + paint index + bitmap index + bool for 'src' + flags
+ uint32_t size = 5 * kUInt32Size;
if (NULL != src) {
size += sizeof(*src); // + rect
}
@@ -927,6 +928,7 @@
addBitmap(bitmap);
addRectPtr(src); // may be null
addRect(dst);
+ addInt(flags);
validate(initialOffset, size);
}

Powered by Google App Engine
This is Rietveld 408576698